@@ -131,6 +131,10 @@
         <source>Repeat new passphrase</source>
         <translation>Повтори парола</translation>
     </message>
+    <message>
+        <source>Show passphrase</source>
+        <translation>Показване на парола</translation>
+    </message>
     <message>
         <source>Encrypt wallet</source>
         <translation>Криптирай портфейл</translation>
@@ -171,6 +175,22 @@
         <source>Wallet encrypted</source>
         <translation>портфейлa е шифрован</translation>
     </message>
+    <message>
+        <source>Enter the old passphrase and new passphrase for the wallet.</source>
+        <translation>Въведете старата и новата паролна фраза за портфейла.</translation>
+    </message>
+    <message>
+        <source>Wallet to be encrypted</source>
+        <translation>Портфейл за криптиране</translation>
+    </message>
+    <message>
+        <source>Your wallet is about to be encrypted. </source>
+        <translation>Портфейлът ви е на път да бъде шифрован.</translation>
+    </message>
+    <message>
+        <source>Your wallet is now encrypted. </source>
+        <translation>Вашият портфейл сега е криптиран.</translation>
+    </message>
     <message>
         <source>IMPORTANT: Any previous backups you have made of your wallet file should be replaced with the newly generated, encrypted wallet file. For security reasons, previous backups of the unencrypted wallet file will become useless as soon as you start using the new, encrypted wallet.</source>
         <translation>ВАЖНО: Всички стари запазвания, които сте направили на Вашият портфейл трябва да замените с запазване на новополучения, шифриран портфейл. От съображения за сигурност, предишните запазвания на нешифрирани портфейли ще станат неизползваеми веднага, щом започнете да използвате новият, шифриран портфейл.</translation>
@@ -437,6 +457,30 @@
         <source>Up to date</source>
         <translation>Актуално</translation>
     </message>
+    <message>
+        <source>Node window</source>
+        <translation>Прозорец на възела</translation>
+    </message>
+    <message>
+        <source>Open Wallet</source>
+        <translation>Отворете портфейл</translation>
+    </message>
+    <message>
+        <source>Close Wallet...</source>
+        <translation>Затвори Портфейла</translation>
+    </message>
+    <message>
+        <source>Close wallet</source>
+        <translation>Затвори портфейла</translation>
+    </message>
+    <message>
+        <source>Close All Wallets...</source>
+        <translation>Затвори Всички Портфейли...</translation>
+    </message>
+    <message>
+        <source>Close all wallets</source>
+        <translation>Затвори всички портфейли</translation>
+    </message>
     <message>
         <source>Show the %1 help message to get a list with possible Bitcoin command-line options</source>
         <translation>Покажи %1 помощно съобщение за да получиш лист с възможни Биткойн команди</translation>
@@ -453,6 +497,14 @@
         <source>Minimize</source>
         <translation>Минимизирай</translation>
     </message>
+    <message>
+        <source>Zoom</source>
+        <translation>Увеличи</translation>
+    </message>
+    <message>
+        <source>Main Window</source>
+        <translation>Главен Прозорец</translation>
+    </message>
     <message>
         <source>%1 client</source>
         <translation>%1 клиент</translation>
@@ -511,11 +563,7 @@
         <source>Wallet is &lt;b&gt;encrypted&lt;/b&gt; and currently &lt;b&gt;locked&lt;/b&gt;</source>
         <translation>Портфейлът е &lt;b&gt;криптиран&lt;/b&gt; и &lt;b&gt;заключен&lt;/b&gt;</translation>
     </message>
-    <message>
-        <source>A fatal error occurred. Bitcoin can no longer continue safely and will quit.</source>
-        <translation>Възникна фатална грешка. Биткойн не може да продължи безопасно и ще се изключи.</translation>
-    </message>
-</context>
+    </context>
 <context>
     <name>CoinControlDialog</name>
     <message>
@@ -646,6 +694,10 @@
         <source>no</source>
         <translation>не</translation>
     </message>
+    <message>
+        <source>This label turns red if any recipient receives an amount smaller than the current dust threshold.</source>
+        <translation>Този етикет става червен ако някой получател получи количество, по-малко от текущия праг на прах</translation>
+    </message>
     <message>
         <source>(no label)</source>
         <translation>(без етикет)</translation>
@@ -661,9 +713,21 @@
 </context>
 <context>
     <name>CreateWalletActivity</name>
+    <message>
+        <source>Create wallet failed</source>
+        <translation>Създаването на портфейл не бе успешен</translation>
+    </message>
     </context>
 <context>
     <name>CreateWalletDialog</name>
+    <message>
+        <source>Create Wallet</source>
+        <translation>Създайте портфейл</translation>
+    </message>
+    <message>
+        <source>Wallet</source>
+        <translation>портфейл</translation>
+    </message>
     </context>
 <context>
     <name>EditAddressDialog</name>
@@ -1060,6 +1124,17 @@
         <translation>Последни транзакции</translation>
     </message>
     </context>
+<context>
+    <name>PSBTOperationsDialog</name>
+    <message>
+        <source>Dialog</source>
+        <translation>Dialog</translation>
+    </message>
+    <message>
+        <source>or</source>
+        <translation>или</translation>
+    </message>
+    </context>
 <context>
     <name>PaymentServer</name>
     <message>
@@ -1230,10 +1305,6 @@
         <source>Number of connections</source>
         <translation>Брой връзки</translation>
     </message>
-    <message>
-        <source>Current number of blocks</source>
-        <translation>Текущ брой блокове</translation>
-    </message>
     <message>
         <source>Received</source>
         <translation>Получени</translation>
@@ -1262,6 +1333,10 @@
         <source>User Agent</source>
         <translation>Потребителски агент</translation>
     </message>
+    <message>
+        <source>Node window</source>
+        <translation>Прозорец на възела</translation>
+    </message>
     <message>
         <source>Services</source>
         <translation>Услуги</translation>
@@ -1334,14 +1409,6 @@
         <source>Outbound</source>
         <translation>Изходящи</translation>
     </message>
-    <message>
-        <source>Yes</source>
-        <translation>Да</translation>
-    </message>
-    <message>
-        <source>No</source>
-        <translation>Не</translation>
-    </message>
     <message>
         <source>Unknown</source>
         <translation>Неизвестен</translation>
@@ -1401,12 +1468,28 @@
         <source>Copy amount</source>
         <translation>Копиране на сумата</translation>
     </message>
-</context>
+    <message>
+        <source>Could not unlock wallet.</source>
+        <translation>Не може да отключите портфейла.</translation>
+    </message>
+    </context>
 <context>
     <name>ReceiveRequestDialog</name>
     <message>
-        <source>QR Code</source>
-        <translation>QR код</translation>
+        <source>Amount:</source>
+        <translation>Количество:</translation>
+    </message>
+    <message>
+        <source>Label:</source>
+        <translation>Име:</translation>
+    </message>
+    <message>
+        <source>Message:</source>
+        <translation>Съобщение:</translation>
+    </message>
+    <message>
+        <source>Wallet:</source>
+        <translation>Портфейл</translation>
     </message>
     <message>
         <source>Copy &amp;URI</source>
@@ -1428,26 +1511,6 @@
         <source>Payment information</source>
         <translation>Данни за плащането</translation>
     </message>
-    <message>
-        <source>Address</source>
-        <translation>Адрес</translation>
-    </message>
-    <message>
-        <source>Amount</source>
-        <translation>Количество</translation>
-    </message>
-    <message>
-        <source>Label</source>
-        <translation>Етикет</translation>
-    </message>
-    <message>
-        <source>Message</source>
-        <translation>Съобщение</translation>
-    </message>
-    <message>
-        <source>Wallet</source>
-        <translation>портфейл</translation>
-    </message>
 </context>
 <context>
     <name>RecentRequestsTableModel</name>
@@ -2188,12 +2251,20 @@
     </context>
 <context>
     <name>WalletController</name>
+    <message>
+        <source>Close wallet</source>
+        <translation>Затвори портфейла</translation>
+    </message>
+    <message>
+        <source>Close all wallets</source>
+        <translation>Затвори всички портфейли</translation>
+    </message>
     </context>
 <context>
     <name>WalletFrame</name>
     <message>
-        <source>No wallet has been loaded.</source>
-        <translation>Няма зареден портфейл.</translation>
+        <source>Create a new wallet</source>
+        <translation>Създай нов портфейл</translation>
     </message>
 </context>
 <context>
@@ -2217,6 +2288,10 @@
         <source>Export the data in the current tab to a file</source>
         <translation>Изнеси данните в избрания раздел към файл</translation>
     </message>
+    <message>
+        <source>Error</source>
+        <translation>грешка</translation>
+    </message>
     <message>
         <source>Backup Wallet</source>
         <translation>Запазване на портфейла</translation>
