@@ -69,6 +69,11 @@
         <source>These are your Bitcoin addresses for sending payments. Always check the amount and the receiving address before sending coins.</source>
         <translation>Jen viaj Bitmon-adresoj por sendi pagojn. Zorge kontrolu la sumon kaj la alsendan adreson antaŭ ol sendi.</translation>
     </message>
+    <message>
+        <source>These are your Bitcoin addresses for receiving payments. Use the 'Create new receiving address' button in the receive tab to create new addresses.
+Signing is only possible with addresses of the type 'legacy'.</source>
+        <translation>Jen viaj bitmonaj adresoj por ricevi pagojn. Estas konsilinde uzi apartan ricevan adreson por ĉiu transakcio.</translation>
+    </message>
     <message>
         <source>&amp;Copy Address</source>
         <translation>&amp;Kopii Adreson</translation>
@@ -131,6 +136,10 @@
         <source>Repeat new passphrase</source>
         <translation>Ripetu la novan pasfrazon</translation>
     </message>
+    <message>
+        <source>Show passphrase</source>
+        <translation>Montri pasfrazon</translation>
+    </message>
     <message>
         <source>Encrypt wallet</source>
         <translation>Ĉifri la monujon</translation>
@@ -171,6 +180,26 @@
         <source>Wallet encrypted</source>
         <translation>La monujo estas ĉifrita</translation>
     </message>
+    <message>
+        <source>Enter the new passphrase for the wallet.&lt;br/&gt;Please use a passphrase of &lt;b&gt;ten or more random characters&lt;/b&gt;, or &lt;b&gt;eight or more words&lt;/b&gt;.</source>
+        <translation>Enigi la novan pasfrazon por la monujo. &lt;br/&gt;Bonvolu uzi pasfrazon de &lt;b&gt;dek aŭ pli hazardaj signoj&lt;/b&gt;, aŭ &lt;b&gt;ok aŭ pli vortoj&lt;/b&gt;.</translation>
+    </message>
+    <message>
+        <source>Enter the old passphrase and new passphrase for the wallet.</source>
+        <translation>Enigi la malnovan pasfrazon kaj la novan pasfrazon por la monujo.</translation>
+    </message>
+    <message>
+        <source>Wallet to be encrypted</source>
+        <translation>Monujo ĉifriĝota</translation>
+    </message>
+    <message>
+        <source>Your wallet is about to be encrypted. </source>
+        <translation>Via monujo estas ĉifriĝota.</translation>
+    </message>
+    <message>
+        <source>Your wallet is now encrypted. </source>
+        <translation>Via monujo ĵus estas ĉifrata.</translation>
+    </message>
     <message>
         <source>IMPORTANT: Any previous backups you have made of your wallet file should be replaced with the newly generated, encrypted wallet file. For security reasons, previous backups of the unencrypted wallet file will become useless as soon as you start using the new, encrypted wallet.</source>
         <translation>GRAVE: antaŭaj sekur-kopioj de via monujo-dosiero estas forigindaj kiam vi havas nove kreitan ĉifritan monujo-dosieron. Pro sekureco, antaŭaj kopioj de la neĉifrita dosiero ne plu funkcios tuj kiam vi ekuzos la novan ĉifritan dosieron.</translation>
@@ -210,7 +239,11 @@
 </context>
 <context>
     <name>BanTableModel</name>
-    </context>
+    <message>
+        <source>Banned Until</source>
+        <translation>Ekzilita Ĝis</translation>
+    </message>
+</context>
 <context>
     <name>BitcoinGUI</name>
     <message>
@@ -249,6 +282,10 @@
         <source>&amp;About %1</source>
         <translation>&amp;Pri %1</translation>
     </message>
+    <message>
+        <source>Show information about %1</source>
+        <translation>Montri informojn pri %1</translation>
+    </message>
     <message>
         <source>About &amp;Qt</source>
         <translation>Pri &amp;Qt</translation>
@@ -261,6 +298,10 @@
         <source>&amp;Options...</source>
         <translation>&amp;Agordoj...</translation>
     </message>
+    <message>
+        <source>Modify configuration options for %1</source>
+        <translation>Ŝanĝi agordojn por %1</translation>
+    </message>
     <message>
         <source>&amp;Encrypt Wallet...</source>
         <translation>Ĉifri &amp;Monujon...</translation>
@@ -277,6 +318,30 @@
         <source>Open &amp;URI...</source>
         <translation>Malfermi &amp;URI-on...</translation>
     </message>
+    <message>
+        <source>Create Wallet...</source>
+        <translation>Krei Monujon...</translation>
+    </message>
+    <message>
+        <source>Create a new wallet</source>
+        <translation>Krei novan monujon</translation>
+    </message>
+    <message>
+        <source>Wallet:</source>
+        <translation>Monujo:</translation>
+    </message>
+    <message>
+        <source>Click to disable network activity.</source>
+        <translation>Alklaki por malebligi retajn agadojn.</translation>
+    </message>
+    <message>
+        <source>Network activity disabled.</source>
+        <translation>Retaj agadoj malebliĝas.</translation>
+    </message>
+    <message>
+        <source>Click to enable network activity again.</source>
+        <translation>Alklaki por denove ebligi retajn agadojn.</translation>
+    </message>
     <message>
         <source>Reindexing blocks on disk...</source>
         <translation>Reindeksado de blokoj sur disko...</translation>
@@ -293,14 +358,6 @@
         <source>Change the passphrase used for wallet encryption</source>
         <translation>Ŝanĝi la pasfrazon por ĉifri la monujon</translation>
     </message>
-    <message>
-        <source>&amp;Debug window</source>
-        <translation>Sen&amp;cimiga fenestro</translation>
-    </message>
-    <message>
-        <source>Open debugging and diagnostic console</source>
-        <translation>Malfermi konzolon de sencimigo kaj diagnozo</translation>
-    </message>
     <message>
         <source>&amp;Verify message...</source>
         <translation>&amp;Kontroli mesaĝon...</translation>
@@ -361,10 +418,6 @@
         <source>Show the list of used receiving addresses and labels</source>
         <translation>Vidigi la liston de uzitaj ricevaj adresoj kaj etikedoj</translation>
     </message>
-    <message>
-        <source>Open a bitcoin: URI or payment request</source>
-        <translation>Malfermi bitcoin:-URI-on aŭ pagpeton</translation>
-    </message>
     <message>
         <source>&amp;Command-line options</source>
         <translation>&amp;Komandliniaj agordaĵoj</translation>
@@ -397,14 +450,58 @@
         <source>Up to date</source>
         <translation>Ĝisdata</translation>
     </message>
+    <message>
+        <source>Open Wallet</source>
+        <translation>Malfermi la Monujon</translation>
+    </message>
+    <message>
+        <source>Open a wallet</source>
+        <translation>Malfermi monujon</translation>
+    </message>
+    <message>
+        <source>Close Wallet...</source>
+        <translation>Fermi la Monujon...</translation>
+    </message>
+    <message>
+        <source>Close wallet</source>
+        <translation>Fermi monujon</translation>
+    </message>
+    <message>
+        <source>Close All Wallets...</source>
+        <translation>Fermi Ĉiujn Monujojn...</translation>
+    </message>
+    <message>
+        <source>Close all wallets</source>
+        <translation>Fermi ĉiujn monujojn</translation>
+    </message>
+    <message>
+        <source>default wallet</source>
+        <translation>defaŭlta monujo</translation>
+    </message>
     <message>
         <source>&amp;Window</source>
         <translation>&amp;Fenestro</translation>
     </message>
+    <message>
+        <source>Zoom</source>
+        <translation>Zomi</translation>
+    </message>
+    <message>
+        <source>Main Window</source>
+        <translation>Ĉefa Fenestro</translation>
+    </message>
     <message>
         <source>Catching up...</source>
         <translation>Ĝisdatigante...</translation>
     </message>
+    <message>
+        <source>Error: %1</source>
+        <translation>Eraro: %1</translation>
+    </message>
+    <message>
+        <source>Warning: %1</source>
+        <translation>Averto: %1</translation>
+    </message>
     <message>
         <source>Date: %1
 </source>
@@ -415,6 +512,12 @@
         <source>Amount: %1
 </source>
         <translation>Sumo: %1
+</translation>
+    </message>
+    <message>
+        <source>Wallet: %1
+</source>
+        <translation>Monujo: %1
 </translation>
     </message>
     <message>
@@ -451,9 +554,21 @@
         <source>Wallet is &lt;b&gt;encrypted&lt;/b&gt; and currently &lt;b&gt;locked&lt;/b&gt;</source>
         <translation>Monujo estas &lt;b&gt;ĉifrita&lt;/b&gt; kaj aktuale &lt;b&gt;ŝlosita&lt;/b&gt;</translation>
     </message>
-    </context>
+    <message>
+        <source>Original message:</source>
+        <translation>Originala mesaĝo:</translation>
+    </message>
+    <message>
+        <source>A fatal error occurred. %1 can no longer continue safely and will quit.</source>
+        <translation>Neriparebla eraro okazis. %1 ne plu sekure povas daŭri kaj ĝi ĉesiĝos.</translation>
+    </message>
+</context>
 <context>
     <name>CoinControlDialog</name>
+    <message>
+        <source>Coin Selection</source>
+        <translation>Monero-Elektaĵo</translation>
+    </message>
     <message>
         <source>Quantity:</source>
         <translation>Kvanto:</translation>
@@ -534,6 +649,14 @@
         <source>Copy transaction ID</source>
         <translation>Kopii transakcian ID-on</translation>
     </message>
+    <message>
+        <source>Lock unspent</source>
+        <translation>Ŝlosi la neelspezitajn</translation>
+    </message>
+    <message>
+        <source>Unlock unspent</source>
+        <translation>Malŝlosi la neelspezitajn</translation>
+    </message>
     <message>
         <source>Copy quantity</source>
         <translation>Kopii kvanton</translation>
@@ -558,16 +681,72 @@
         <source>Copy change</source>
         <translation>Kopii restmonon</translation>
     </message>
+    <message>
+        <source>(%1 locked)</source>
+        <translation>(%1 ŝlosita)</translation>
+    </message>
+    <message>
+        <source>yes</source>
+        <translation>jes</translation>
+    </message>
+    <message>
+        <source>no</source>
+        <translation>ne</translation>
+    </message>
     <message>
         <source>(no label)</source>
         <translation>(neniu etikedo)</translation>
     </message>
-    </context>
+    <message>
+        <source>change from %1 (%2)</source>
+        <translation>restmono de %1 (%2)</translation>
+    </message>
+    <message>
+        <source>(change)</source>
+        <translation>(restmono)</translation>
+    </message>
+</context>
 <context>
     <name>CreateWalletActivity</name>
-    </context>
+    <message>
+        <source>Create wallet failed</source>
+        <translation>Krei monujon malsukcesis</translation>
+    </message>
+    <message>
+        <source>Create wallet warning</source>
+        <translation>Averto pro krei monujon</translation>
+    </message>
+</context>
 <context>
     <name>CreateWalletDialog</name>
+    <message>
+        <source>Create Wallet</source>
+        <translation>Krei Monujon</translation>
+    </message>
+    <message>
+        <source>Wallet</source>
+        <translation>Monujo</translation>
+    </message>
+    <message>
+        <source>Wallet Name</source>
+        <translation>Monujo-Nomo</translation>
+    </message>
+    <message>
+        <source>Encrypt Wallet</source>
+        <translation>Ĉifri Monujon</translation>
+    </message>
+    <message>
+        <source>Disable private keys for this wallet. Wallets with private keys disabled will have no private keys and cannot have an HD seed or imported private keys. This is ideal for watch-only wallets.</source>
+        <translation>Malebligi privatajn ŝlosilojn por ĉi tiu monujo. Monujoj kun malebligitaj privataj ŝlosiloj ne havos privatajn ŝlosilojn, kaj povas havi nek HD-semon nek importatajn privatajn ŝlosilojn. Ĉi tio estas ideale por nurspektaj monujoj.</translation>
+    </message>
+    <message>
+        <source>Disable Private Keys</source>
+        <translation>Malebligi Privatajn Ŝlosilojn</translation>
+    </message>
+    <message>
+        <source>Create</source>
+        <translation>Krei</translation>
+    </message>
     </context>
 <context>
     <name>EditAddressDialog</name>
@@ -591,7 +770,31 @@
         <source>&amp;Address</source>
         <translation>&amp;Adreso</translation>
     </message>
-    </context>
+    <message>
+        <source>New sending address</source>
+        <translation>Nova adreso por sendi</translation>
+    </message>
+    <message>
+        <source>Edit receiving address</source>
+        <translation>Redakti adreson por ricevi</translation>
+    </message>
+    <message>
+        <source>Edit sending address</source>
+        <translation>Redakti adreson por sendi</translation>
+    </message>
+    <message>
+        <source>The entered address "%1" is not a valid Bitcoin address.</source>
+        <translation>La adreso enigita "%1" ne estas valida Bitmon-adreso.</translation>
+    </message>
+    <message>
+        <source>Could not unlock wallet.</source>
+        <translation>Ne eblis malŝlosi monujon.</translation>
+    </message>
+    <message>
+        <source>New key generation failed.</source>
+        <translation>Fiaskis kreo de nova ŝlosilo.</translation>
+    </message>
+</context>
 <context>
     <name>FreespaceChecker</name>
     <message>
@@ -621,6 +824,10 @@
         <source>version</source>
         <translation>versio</translation>
     </message>
+    <message>
+        <source>About %1</source>
+        <translation>Pri %1</translation>
+    </message>
     <message>
         <source>Command-line options</source>
         <translation>Komandliniaj agordaĵoj</translation>
@@ -632,6 +839,10 @@
         <source>Welcome</source>
         <translation>Bonvenon</translation>
     </message>
+    <message>
+        <source>Welcome to %1.</source>
+        <translation>Bonvenon al %1.</translation>
+    </message>
     <message>
         <source>Use the default data directory</source>
         <translation>Uzi la defaŭltan dosierujon por datumoj</translation>
@@ -659,33 +870,69 @@
         <source>Form</source>
         <translation>Formularo</translation>
     </message>
+    <message>
+        <source>Unknown...</source>
+        <translation>Nekonata...</translation>
+    </message>
     <message>
         <source>Last block time</source>
         <translation>Horo de la lasta bloko</translation>
     </message>
+    <message>
+        <source>Progress</source>
+        <translation>Progreso</translation>
+    </message>
+    <message>
+        <source>Progress increase per hour</source>
+        <translation>Hora pligrandigo da progreso</translation>
+    </message>
+    <message>
+        <source>calculating...</source>
+        <translation>kalkuladas...</translation>
+    </message>
+    <message>
+        <source>Hide</source>
+        <translation>Kaŝi</translation>
+    </message>
+    <message>
+        <source>Esc</source>
+        <translation>Esk</translation>
+    </message>
+    <message>
+        <source>%1 is currently syncing.  It will download headers and blocks from peers and validate them until reaching the tip of the block chain.</source>
+        <translation>%1 sinkronigadas. Ĝi elŝutos kapaĵojn kaj blokojn de samtavolanoj, kaj validigos ilin, ĝis ĝi atingas la pinton de la blokĉeno.</translation>
+    </message>
     </context>
 <context>
     <name>OpenURIDialog</name>
     <message>
-        <source>Open URI</source>
-        <translation>Malfermi URI-on</translation>
-    </message>
-    <message>
-        <source>Open payment request from URI or file</source>
-        <translation>Malfermi pagpeton el URI aŭ dosiero</translation>
+        <source>Open bitcoin URI</source>
+        <translation>Malfermi na la URI de bitmono</translation>
     </message>
     <message>
         <source>URI:</source>
         <translation>URI:</translation>
     </message>
-    <message>
-        <source>Select payment request file</source>
-        <translation>Elektu la dosieron de la pagpeto</translation>
-    </message>
-    </context>
+</context>
 <context>
     <name>OpenWalletActivity</name>
-    </context>
+    <message>
+        <source>Open wallet failed</source>
+        <translation>Malfermi monujon malsukcesis</translation>
+    </message>
+    <message>
+        <source>Open wallet warning</source>
+        <translation>Malfermi monujon averto</translation>
+    </message>
+    <message>
+        <source>default wallet</source>
+        <translation>defaŭlta monujo</translation>
+    </message>
+    <message>
+        <source>Opening Wallet &lt;b&gt;%1&lt;/b&gt;...</source>
+        <translation>Malfermadas Monujon &lt;b&gt;%1&lt;/b&gt;...</translation>
+    </message>
+</context>
 <context>
     <name>OptionsDialog</name>
     <message>
@@ -696,10 +943,26 @@
         <source>&amp;Main</source>
         <translation>Ĉ&amp;efa</translation>
     </message>
+    <message>
+        <source>Automatically start %1 after logging in to the system.</source>
+        <translation>Aŭtomate komenci na %1 post ensalutis en la sistemon.</translation>
+    </message>
+    <message>
+        <source>&amp;Start %1 on system login</source>
+        <translation>&amp;Komenci na %1 kiam ensaluti en la sistemon</translation>
+    </message>
     <message>
         <source>Size of &amp;database cache</source>
         <translation>Dosiergrando de &amp;datumbasa kaŝmemoro</translation>
     </message>
+    <message>
+        <source>Number of script &amp;verification threads</source>
+        <translation>Kvanto da skriptaj kaj kontroleraraj fadenoj</translation>
+    </message>
+    <message>
+        <source>IP address of the proxy (e.g. IPv4: 127.0.0.1 / IPv6: ::1)</source>
+        <translation>IP-adreso de prokurilo (ekz. IPv4: 127.0.0.1 / IPv6: ::1)</translation>
+    </message>
     <message>
         <source>Reset all client options to default.</source>
         <translation>Reagordi ĉion al defaŭlataj valoroj.</translation>
@@ -823,6 +1086,10 @@
         <source>The displayed information may be out of date. Your wallet automatically synchronizes with the Bitcoin network after a connection is established, but this process has not completed yet.</source>
         <translation>Eblas, ke la informoj videblaj ĉi tie estas eksdataj. Via monujo aŭtomate sinkoniĝas kun la bitmona reto kiam ili konektiĝas, sed tiu procezo ankoraŭ ne finfariĝis.</translation>
     </message>
+    <message>
+        <source>Available:</source>
+        <translation>Disponebla:</translation>
+    </message>
     <message>
         <source>Your current spendable balance</source>
         <translation>via aktuala elspezebla saldo</translation>
@@ -860,8 +1127,43 @@
         <translation>Lastaj transakcioj</translation>
     </message>
     </context>
+<context>
+    <name>PSBTOperationsDialog</name>
+    <message>
+        <source>Save...</source>
+        <translation>Konservi...</translation>
+    </message>
+    <message>
+        <source>Close</source>
+        <translation>Fermi</translation>
+    </message>
+    <message>
+        <source>Total Amount</source>
+        <translation>Totala Sumo</translation>
+    </message>
+    <message>
+        <source>or</source>
+        <translation>aŭ</translation>
+    </message>
+    </context>
 <context>
     <name>PaymentServer</name>
+    <message>
+        <source>Payment request error</source>
+        <translation>Eraro dum pagopeto</translation>
+    </message>
+    <message>
+        <source>Cannot start bitcoin: click-to-pay handler</source>
+        <translation>Ne eblas lanĉi la ilon 'klaki-por-pagi'</translation>
+    </message>
+    <message>
+        <source>URI handling</source>
+        <translation>Traktado de URI-oj</translation>
+    </message>
+    <message>
+        <source>Invalid payment address %1</source>
+        <translation>Nevalida pagadreso %1</translation>
+    </message>
     </context>
 <context>
     <name>PeerTableModel</name>
@@ -900,10 +1202,34 @@
         <source>N/A</source>
         <translation>neaplikebla</translation>
     </message>
+    <message numerus="yes">
+        <source>%n second(s)</source>
+        <translation><numerusform>%n sekundo</numerusform><numerusform>%n sekundoj</numerusform></translation>
+    </message>
+    <message numerus="yes">
+        <source>%n minute(s)</source>
+        <translation><numerusform>%n minuto</numerusform><numerusform>%n minutoj</numerusform></translation>
+    </message>
+    <message numerus="yes">
+        <source>%n hour(s)</source>
+        <translation><numerusform>%n horo</numerusform><numerusform>%n horoj</numerusform></translation>
+    </message>
+    <message numerus="yes">
+        <source>%n day(s)</source>
+        <translation><numerusform>%n tago</numerusform><numerusform>%n tagoj</numerusform></translation>
+    </message>
+    <message numerus="yes">
+        <source>%n week(s)</source>
+        <translation><numerusform>%n semajno</numerusform><numerusform>%n semajnoj</numerusform></translation>
+    </message>
     <message>
         <source>%1 and %2</source>
         <translation>%1 kaj %2</translation>
     </message>
+    <message numerus="yes">
+        <source>%n year(s)</source>
+        <translation><numerusform>%n jaro</numerusform><numerusform>%n jaroj</numerusform></translation>
+    </message>
     <message>
         <source>%1 B</source>
         <translation>%1 B</translation>
@@ -924,6 +1250,10 @@
         <source>Error: Specified data directory "%1" does not exist.</source>
         <translation>Eraro: la elektita dosierujo por datumoj "%1" ne ekzistas.</translation>
     </message>
+    <message>
+        <source>Error: %1</source>
+        <translation>Eraro: %1</translation>
+    </message>
     <message>
         <source>unknown</source>
         <translation>nekonata</translation>
@@ -935,6 +1265,10 @@
         <source>&amp;Save Image...</source>
         <translation>&amp;Konservi Bildon...</translation>
     </message>
+    <message>
+        <source>&amp;Copy Image</source>
+        <translation>&amp;Kopii Bildon</translation>
+    </message>
     <message>
         <source>Resulting URI too long, try to reduce the text for label / message.</source>
         <translation>La rezultanta URI estas tro longa. Provu malplilongigi la tekston de la etikedo / mesaĝo.</translation>
@@ -943,7 +1277,15 @@
         <source>Error encoding URI into QR Code.</source>
         <translation>Eraro de kodigo de URI en la QR-kodon.</translation>
     </message>
-    </context>
+    <message>
+        <source>Save QR Code</source>
+        <translation>Konservi QR-kodon</translation>
+    </message>
+    <message>
+        <source>PNG Image (*.png)</source>
+        <translation>PNG-bildo (*.png)</translation>
+    </message>
+</context>
 <context>
     <name>RPCConsole</name>
     <message>
@@ -958,10 +1300,6 @@
         <source>&amp;Information</source>
         <translation>&amp;Informoj</translation>
     </message>
-    <message>
-        <source>Debug window</source>
-        <translation>Sencimiga fenestro</translation>
-    </message>
     <message>
         <source>General</source>
         <translation>Ĝenerala</translation>
@@ -987,8 +1325,8 @@
         <translation>Blokĉeno</translation>
     </message>
     <message>
-        <source>Current number of blocks</source>
-        <translation>Aktuala nombro de blokoj</translation>
+        <source>Wallet: </source>
+        <translation>Monujo:</translation>
     </message>
     <message>
         <source>Received</source>
@@ -1054,7 +1392,35 @@
         <source>Clear console</source>
         <translation>Malplenigi konzolon</translation>
     </message>
-    </context>
+    <message>
+        <source>1 &amp;hour</source>
+        <translation>1 &amp;horo</translation>
+    </message>
+    <message>
+        <source>1 &amp;day</source>
+        <translation>1 &amp;tago</translation>
+    </message>
+    <message>
+        <source>1 &amp;week</source>
+        <translation>1 &amp;semajno</translation>
+    </message>
+    <message>
+        <source>1 &amp;year</source>
+        <translation>1 &amp;jaro</translation>
+    </message>
+    <message>
+        <source>&amp;Unban</source>
+        <translation>&amp;Malekzili</translation>
+    </message>
+    <message>
+        <source>never</source>
+        <translation>neniam</translation>
+    </message>
+    <message>
+        <source>Unknown</source>
+        <translation>Nekonata</translation>
+    </message>
+</context>
 <context>
     <name>ReceiveCoinsDialog</name>
     <message>
@@ -1097,12 +1463,32 @@
         <source>Copy amount</source>
         <translation>Kopii sumon</translation>
     </message>
-</context>
+    <message>
+        <source>Could not unlock wallet.</source>
+        <translation>Ne eblis malŝlosi monujon.</translation>
+    </message>
+    </context>
 <context>
     <name>ReceiveRequestDialog</name>
     <message>
-        <source>QR Code</source>
-        <translation>QR-kodo</translation>
+        <source>Address:</source>
+        <translation>Adreso:</translation>
+    </message>
+    <message>
+        <source>Amount:</source>
+        <translation>Sumo:</translation>
+    </message>
+    <message>
+        <source>Label:</source>
+        <translation>Etikedo:</translation>
+    </message>
+    <message>
+        <source>Message:</source>
+        <translation>Mesaĝo:</translation>
+    </message>
+    <message>
+        <source>Wallet:</source>
+        <translation>Monujo:</translation>
     </message>
     <message>
         <source>Copy &amp;URI</source>
@@ -1124,30 +1510,6 @@
         <source>Payment information</source>
         <translation>Paginformoj</translation>
     </message>
-    <message>
-        <source>URI</source>
-        <translation>URI</translation>
-    </message>
-    <message>
-        <source>Address</source>
-        <translation>Adreso</translation>
-    </message>
-    <message>
-        <source>Amount</source>
-        <translation>Sumo</translation>
-    </message>
-    <message>
-        <source>Label</source>
-        <translation>Etikedo</translation>
-    </message>
-    <message>
-        <source>Message</source>
-        <translation>Mesaĝo</translation>
-    </message>
-    <message>
-        <source>Wallet</source>
-        <translation>Monujo</translation>
-    </message>
 </context>
 <context>
     <name>RecentRequestsTableModel</name>
@@ -1218,6 +1580,10 @@
         <source>Transaction Fee:</source>
         <translation>Krompago:</translation>
     </message>
+    <message>
+        <source>Hide</source>
+        <translation>Kaŝi</translation>
+    </message>
     <message>
         <source>Send to multiple recipients at once</source>
         <translation>Sendi samtempe al pluraj ricevantoj</translation>
@@ -1294,10 +1660,18 @@
         <source>Transaction fee</source>
         <translation>Krompago</translation>
     </message>
+    <message>
+        <source>Total Amount</source>
+        <translation>Totala Sumo</translation>
+    </message>
     <message>
         <source>Confirm send coins</source>
         <translation>Konfirmi sendon de bitmono</translation>
     </message>
+    <message>
+        <source>Send</source>
+        <translation>Sendi</translation>
+    </message>
     <message>
         <source>The amount to pay must be larger than 0.</source>
         <translation>La pagenda sumo devas esti pli ol 0.</translation>
@@ -1341,10 +1715,6 @@
         <source>Choose previously used address</source>
         <translation>Elektu la jam uzitan adreson</translation>
     </message>
-    <message>
-        <source>This is a normal payment.</source>
-        <translation>Tio estas normala pago.</translation>
-    </message>
     <message>
         <source>Alt+A</source>
         <translation>Alt+A</translation>
@@ -1377,14 +1747,7 @@
         <source>Memo:</source>
         <translation>Memorando:</translation>
     </message>
-    <message>
-        <source>Enter a label for this address to add it to your address book</source>
-        <translation>Tajpu etikedon por tiu ĉi adreso kaj aldonu ĝin al via adresaro</translation>
-    </message>
 </context>
-<context>
-    <name>SendConfirmationDialog</name>
-    </context>
 <context>
     <name>ShutdownWindow</name>
     <message>
@@ -1843,17 +2206,33 @@
     </context>
 <context>
     <name>WalletController</name>
+    <message>
+        <source>Close wallet</source>
+        <translation>Fermi monujon</translation>
+    </message>
+    <message>
+        <source>Close all wallets</source>
+        <translation>Fermi ĉiujn monujojn</translation>
+    </message>
     </context>
 <context>
     <name>WalletFrame</name>
-    </context>
+    <message>
+        <source>Create a new wallet</source>
+        <translation>Krei novan monujon</translation>
+    </message>
+</context>
 <context>
     <name>WalletModel</name>
     <message>
         <source>Send Coins</source>
         <translation>Sendi Bitmonon</translation>
     </message>
-    </context>
+    <message>
+        <source>default wallet</source>
+        <translation>defaŭlta monujo</translation>
+    </message>
+</context>
 <context>
     <name>WalletView</name>
     <message>
@@ -1864,6 +2243,10 @@
         <source>Export the data in the current tab to a file</source>
         <translation>Eksporti la datumojn el la aktuala langeto al dosiero</translation>
     </message>
+    <message>
+        <source>Error</source>
+        <translation>Eraro</translation>
+    </message>
     <message>
         <source>Backup Wallet</source>
         <translation>Krei sekurkopion de monujo</translation>
