@@ -175,6 +175,10 @@
         <source>Wallet encrypted</source>
         <translation>Monedero cifrado</translation>
     </message>
+    <message>
+        <source>Enter the new passphrase for the wallet.&lt;br/&gt;Please use a passphrase of &lt;b&gt;ten or more random characters&lt;/b&gt;, or &lt;b&gt;eight or more words&lt;/b&gt;.</source>
+        <translation>Ingrese la nueva contraseña para la billetera. Use una contraseña de diez o más caracteres aleatorios, u ocho o más palabras.</translation>
+    </message>
     <message>
         <source>Wallet to be encrypted</source>
         <translation>Billetera a ser cifrada</translation>
@@ -590,6 +594,10 @@
     </context>
 <context>
     <name>CreateWalletDialog</name>
+    <message>
+        <source>Wallet</source>
+        <translation>Monedero</translation>
+    </message>
     </context>
 <context>
     <name>EditAddressDialog</name>
