@@ -461,6 +461,10 @@
         <source>Catching up...</source>
         <translation>Jõuan järgi...</translation>
     </message>
+    <message>
+        <source>Error: %1</source>
+        <translation>Tõrge %1</translation>
+    </message>
     <message>
         <source>Date: %1
 </source>
@@ -507,11 +511,7 @@
         <source>Wallet is &lt;b&gt;encrypted&lt;/b&gt; and currently &lt;b&gt;locked&lt;/b&gt;</source>
         <translation>Rahakott on &lt;b&gt;krüpteeritud&lt;/b&gt; ning hetkel &lt;b&gt;suletud&lt;/b&gt;</translation>
     </message>
-    <message>
-        <source>A fatal error occurred. Bitcoin can no longer continue safely and will quit.</source>
-        <translation>Ilmnes kriitiline tõrge. Bitcoin suletakse turvakaalutluste tõttu.</translation>
-    </message>
-</context>
+    </context>
 <context>
     <name>CoinControlDialog</name>
     <message>
@@ -636,6 +636,10 @@
     </context>
 <context>
     <name>CreateWalletDialog</name>
+    <message>
+        <source>Wallet</source>
+        <translation>Rahakott</translation>
+    </message>
     </context>
 <context>
     <name>EditAddressDialog</name>
@@ -865,7 +869,7 @@
     </message>
     <message>
         <source>The displayed information may be out of date. Your wallet automatically synchronizes with the Bitcoin network after a connection is established, but this process has not completed yet.</source>
-        <translation>Kuvatav info ei pruugi olla ajakohane. Ühenduse loomisel süngitakse sinu rahakott automaatselt Bitconi võrgustikuga, kuid see toiming on hetkel lõpetamata.</translation>
+        <translation>Kuvatav info ei pruugi olla ajakohane. Ühenduse loomisel süngitakse sinu rahakott automaatselt Bitcoin võrgustikuga, kuid see toiming on hetkel lõpetamata.</translation>
     </message>
     <message>
         <source>Pending:</source>
@@ -888,6 +892,17 @@
         <translation>Hiljutised transaktsioonid</translation>
     </message>
     </context>
+<context>
+    <name>PSBTOperationsDialog</name>
+    <message>
+        <source>Dialog</source>
+        <translation>Dialoog</translation>
+    </message>
+    <message>
+        <source>or</source>
+        <translation>või</translation>
+    </message>
+    </context>
 <context>
     <name>PaymentServer</name>
     <message>
@@ -964,6 +979,10 @@
         <source>%1 GB</source>
         <translation>%1 GB</translation>
     </message>
+    <message>
+        <source>Error: %1</source>
+        <translation>Tõrge %1</translation>
+    </message>
     <message>
         <source>unknown</source>
         <translation>tundmatu</translation>
@@ -1034,10 +1053,6 @@
         <source>Block chain</source>
         <translation>Blokiahel</translation>
     </message>
-    <message>
-        <source>Current number of blocks</source>
-        <translation>Plokkide hetkearv</translation>
-    </message>
     <message>
         <source>Memory usage</source>
         <translation>Mälu kasutus</translation>
@@ -1114,14 +1129,6 @@
         <source>Outbound</source>
         <translation>Väljuv</translation>
     </message>
-    <message>
-        <source>Yes</source>
-        <translation>Jah</translation>
-    </message>
-    <message>
-        <source>No</source>
-        <translation>Ei</translation>
-    </message>
     <message>
         <source>Unknown</source>
         <translation>Teadmata</translation>
@@ -1165,12 +1172,28 @@
         <source>Copy amount</source>
         <translation>Kopeeri kogus</translation>
     </message>
-</context>
+    <message>
+        <source>Could not unlock wallet.</source>
+        <translation>Rahakoti lahtilukustamine ebaõnnestus.</translation>
+    </message>
+    </context>
 <context>
     <name>ReceiveRequestDialog</name>
     <message>
-        <source>QR Code</source>
-        <translation>QR Kood</translation>
+        <source>Amount:</source>
+        <translation>Kogus</translation>
+    </message>
+    <message>
+        <source>Label:</source>
+        <translation>Märgis:</translation>
+    </message>
+    <message>
+        <source>Message:</source>
+        <translation>Sõnum:</translation>
+    </message>
+    <message>
+        <source>Wallet:</source>
+        <translation>Rahakott:</translation>
     </message>
     <message>
         <source>Copy &amp;Address</source>
@@ -1184,26 +1207,6 @@
         <source>Payment information</source>
         <translation>Makse Informatsioon</translation>
     </message>
-    <message>
-        <source>Address</source>
-        <translation>Aadress</translation>
-    </message>
-    <message>
-        <source>Amount</source>
-        <translation>Kogus</translation>
-    </message>
-    <message>
-        <source>Label</source>
-        <translation>Silt</translation>
-    </message>
-    <message>
-        <source>Message</source>
-        <translation>Sõnum</translation>
-    </message>
-    <message>
-        <source>Wallet</source>
-        <translation>Rahakott</translation>
-    </message>
 </context>
 <context>
     <name>RecentRequestsTableModel</name>
@@ -1903,7 +1906,11 @@
     </context>
 <context>
     <name>WalletFrame</name>
-    </context>
+    <message>
+        <source>Create a new wallet</source>
+        <translation>Loo uus rahakott</translation>
+    </message>
+</context>
 <context>
     <name>WalletModel</name>
     <message>
@@ -1921,6 +1928,10 @@
         <source>Export the data in the current tab to a file</source>
         <translation>Ekspordi kuvatava vahelehe sisu faili</translation>
     </message>
+    <message>
+        <source>Error</source>
+        <translation>Viga</translation>
+    </message>
     <message>
         <source>Backup Wallet</source>
         <translation>Varunda Rahakott</translation>
