@@ -353,10 +353,18 @@
         <source>Reindexing blocks on disk...</source>
         <translation>Blokeak diskoan berriro zerrendatzen...</translation>
     </message>
+    <message>
+        <source>Proxy is &lt;b&gt;enabled&lt;/b&gt;: %1</source>
+        <translation>Proxya &lt;b&gt;gaituta&lt;/b&gt; dago : %1</translation>
+    </message>
     <message>
         <source>Send coins to a Bitcoin address</source>
         <translation>Bidali txanponak Bitcoin helbide batera</translation>
     </message>
+    <message>
+        <source>Backup wallet to another location</source>
+        <translation>Diru-zorroaren segurtasun-kopia beste leku batean.</translation>
+    </message>
     <message>
         <source>Change the passphrase used for wallet encryption</source>
         <translation>Diruzorroa enkriptatzeko erabilitako pasahitza aldatu</translation>
@@ -381,6 +389,14 @@
         <source>Show or hide the main Window</source>
         <translation>Lehio nagusia erakutsi edo izkutatu</translation>
     </message>
+    <message>
+        <source>Encrypt the private keys that belong to your wallet</source>
+        <translation>Zure diru-zorroari dagozkion giltza pribatuak enkriptatu.</translation>
+    </message>
+    <message>
+        <source>Sign messages with your Bitcoin addresses to prove you own them</source>
+        <translation>Sinatu mezuak Bitcoinen helbideekin, zure jabea zarela frogatzeko.</translation>
+    </message>
     <message>
         <source>Verify messages to ensure they were signed with specified Bitcoin addresses</source>
         <translation>Egiaztatu mesua Bitcoin helbide espezifikoarekin erregistratu direla ziurtatzeko</translation>
@@ -401,14 +417,46 @@
         <source>Tabs toolbar</source>
         <translation>Fitxen tresna-barra</translation>
     </message>
+    <message>
+        <source>Show the list of used sending addresses and labels</source>
+        <translation>Erakutsi bidalketa-helbideen eta etiketen zerrenda</translation>
+    </message>
+    <message>
+        <source>Show the list of used receiving addresses and labels</source>
+        <translation>Harrera-helbideen eta etiketen zerrenda erakutsi</translation>
+    </message>
+    <message>
+        <source>&amp;Command-line options</source>
+        <translation>&amp;Komando-lerroaren aukerak</translation>
+    </message>
+    <message>
+        <source>Indexing blocks on disk...</source>
+        <translation>Blokeak diskoan indexatzen...</translation>
+    </message>
+    <message>
+        <source>Processing blocks on disk...</source>
+        <translation>Blokeak diskoan prozesatzen...</translation>
+    </message>
     <message>
         <source>%1 behind</source>
         <translation>%1 atzetik</translation>
     </message>
+    <message>
+        <source>Last received block was generated %1 ago.</source>
+        <translation>Jasotako azken blokea duela %1 sortu zen.</translation>
+    </message>
+    <message>
+        <source>Transactions after this will not yet be visible.</source>
+        <translation>Honen ondorengo transakzioak oraindik ez daude ikusgai.</translation>
+    </message>
     <message>
         <source>Error</source>
         <translation>Akatsa</translation>
     </message>
+    <message>
+        <source>Warning</source>
+        <translation>Abisua</translation>
+    </message>
     <message>
         <source>Information</source>
         <translation>Informazioa</translation>
@@ -417,6 +465,10 @@
         <source>Up to date</source>
         <translation>Eguneratua</translation>
     </message>
+    <message>
+        <source>Node window</source>
+        <translation>Adabegiaren leihoa</translation>
+    </message>
     <message>
         <source>&amp;Sending addresses</source>
         <translation>&amp;Helbideak bidaltzen</translation>
@@ -425,6 +477,10 @@
         <source>&amp;Receiving addresses</source>
         <translation>&amp;Helbideak jasotzen</translation>
     </message>
+    <message>
+        <source>Open a bitcoin: URI</source>
+        <translation>Ireki bitcoin bat: URI</translation>
+    </message>
     <message>
         <source>Open Wallet</source>
         <translation>Diruzorroa zabaldu</translation>
@@ -441,10 +497,22 @@
         <source>Close wallet</source>
         <translation>Diruzorroa itxi</translation>
     </message>
+    <message>
+        <source>Close All Wallets...</source>
+        <translation>Diruzorro guztiak itxi...</translation>
+    </message>
+    <message>
+        <source>Close all wallets</source>
+        <translation>Diruzorro guztiak itxi</translation>
+    </message>
     <message>
         <source>default wallet</source>
         <translation>Diruzorro lehenetsia</translation>
     </message>
+    <message>
+        <source>No wallets available</source>
+        <translation>Ez dago diru-zorrorik eskura</translation>
+    </message>
     <message>
         <source>&amp;Window</source>
         <translation>&amp;Lehioa</translation>
@@ -461,6 +529,14 @@
         <source>Main Window</source>
         <translation>Lehio nagusia</translation>
     </message>
+    <message>
+        <source>%1 client</source>
+        <translation>%1 bezeroa</translation>
+    </message>
+    <message>
+        <source>Connecting to peers...</source>
+        <translation>Pareekin konektatzen...</translation>
+    </message>
     <message>
         <source>Catching up...</source>
         <translation>Eguneratzen...</translation>
@@ -491,6 +567,11 @@
         <translation>Diruzorroa: %1
 </translation>
     </message>
+    <message>
+        <source>Type: %1
+</source>
+        <translation>Mota: %1</translation>
+    </message>
     <message>
         <source>Label: %1
 </source>
@@ -511,6 +592,18 @@
         <source>Incoming transaction</source>
         <translation>Sartutako transakzioa</translation>
     </message>
+    <message>
+        <source>HD key generation is &lt;b&gt;enabled&lt;/b&gt;</source>
+        <translation>HD gakoa sortzea &lt;b&gt;gaituta&lt;/b&gt; dago</translation>
+    </message>
+    <message>
+        <source>HD key generation is &lt;b&gt;disabled&lt;/b&gt;</source>
+        <translation>HD gakoa sortzea &lt;b&gt;desgaituta&lt;/b&gt; dago</translation>
+    </message>
+    <message>
+        <source>Private key &lt;b&gt;disabled&lt;/b&gt;</source>
+        <translation>Gako pribatua &lt;b&gt;desgaitua&lt;/b&gt;</translation>
+    </message>
     <message>
         <source>Wallet is &lt;b&gt;encrypted&lt;/b&gt; and currently &lt;b&gt;unlocked&lt;/b&gt;</source>
         <translation>Zorroa &lt;b&gt;enkriptatuta&lt;/b&gt; eta &lt;b&gt;desblokeatuta&lt;/b&gt; dago une honetan</translation>
@@ -519,6 +612,10 @@
         <source>Wallet is &lt;b&gt;encrypted&lt;/b&gt; and currently &lt;b&gt;locked&lt;/b&gt;</source>
         <translation>Zorroa &lt;b&gt;enkriptatuta&lt;/b&gt; eta &lt;b&gt;blokeatuta&lt;/b&gt; dago une honetan</translation>
     </message>
+    <message>
+        <source>Original message:</source>
+        <translation>Jatorrizko mezua:</translation>
+    </message>
     </context>
 <context>
     <name>CoinControlDialog</name>
@@ -538,18 +635,42 @@
         <source>Amount:</source>
         <translation>Kopurua:</translation>
     </message>
+    <message>
+        <source>Fee:</source>
+        <translation>Ordainketa:</translation>
+    </message>
     <message>
         <source>Dust:</source>
         <translation>Hautsa:</translation>
     </message>
+    <message>
+        <source>After Fee:</source>
+        <translation>Ordaindu ondoren:</translation>
+    </message>
     <message>
         <source>Change:</source>
         <translation>Bueltak:</translation>
     </message>
+    <message>
+        <source>Tree mode</source>
+        <translation>Zuhaitz modua</translation>
+    </message>
+    <message>
+        <source>List mode</source>
+        <translation>Zerrenda modua</translation>
+    </message>
     <message>
         <source>Amount</source>
         <translation>Kopurua</translation>
     </message>
+    <message>
+        <source>Received with label</source>
+        <translation>Etiketarekin jasoa</translation>
+    </message>
+    <message>
+        <source>Received with address</source>
+        <translation>Helbidearekin jasoa</translation>
+    </message>
     <message>
         <source>Date</source>
         <translation>Data</translation>
@@ -570,6 +691,42 @@
         <source>Copy label</source>
         <translation>Etiketa kopiatu</translation>
     </message>
+    <message>
+        <source>Copy amount</source>
+        <translation>zenbatekoaren kopia</translation>
+    </message>
+    <message>
+        <source>Copy transaction ID</source>
+        <translation>Kopiatu transakzioaren IDa</translation>
+    </message>
+    <message>
+        <source>Lock unspent</source>
+        <translation>Blokeatu erabili gabe</translation>
+    </message>
+    <message>
+        <source>Unlock unspent</source>
+        <translation>Desblokeatu gastatu gabe</translation>
+    </message>
+    <message>
+        <source>Copy quantity</source>
+        <translation>Kopia kopurua</translation>
+    </message>
+    <message>
+        <source>Copy bytes</source>
+        <translation>Kopiatu byte-ak</translation>
+    </message>
+    <message>
+        <source>Copy dust</source>
+        <translation>Kopiatu hautsa</translation>
+    </message>
+    <message>
+        <source>Copy change</source>
+        <translation>Kopiatu aldaketa</translation>
+    </message>
+    <message>
+        <source>(%1 locked)</source>
+        <translation>(%1 blokeatuta)</translation>
+    </message>
     <message>
         <source>yes</source>
         <translation>bai</translation>
@@ -597,13 +754,21 @@
         <source>Create wallet failed</source>
         <translation>Diruzorroa sortzen hutsegitea</translation>
     </message>
-    </context>
+    <message>
+        <source>Create wallet warning</source>
+        <translation>Diru-zorroa sortzearen buruzko oharra</translation>
+    </message>
+</context>
 <context>
     <name>CreateWalletDialog</name>
     <message>
         <source>Create Wallet</source>
         <translation>Diruzorroa sortu</translation>
     </message>
+    <message>
+        <source>Wallet</source>
+        <translation>Diru-zorroa</translation>
+    </message>
     <message>
         <source>Wallet Name</source>
         <translation>Diruzorroaren izena</translation>
@@ -612,6 +777,18 @@
         <source>Encrypt Wallet</source>
         <translation>Diruzorroa enkriptatu</translation>
     </message>
+    <message>
+        <source>Advanced Options</source>
+        <translation>Aukera aurreratuak</translation>
+    </message>
+    <message>
+        <source>Disable Private Keys</source>
+        <translation>Desgaitu gako pribatuak</translation>
+    </message>
+    <message>
+        <source>Descriptor Wallet</source>
+        <translation>Deskriptorearen zorroa</translation>
+    </message>
     <message>
         <source>Create</source>
         <translation>Sortu</translation>
@@ -665,7 +842,15 @@
         <source>version</source>
         <translation>bertsioa</translation>
     </message>
-    </context>
+    <message>
+        <source>About %1</source>
+        <translation>%1 inguru</translation>
+    </message>
+    <message>
+        <source>Command-line options</source>
+        <translation>Komando lerroaren aukerak</translation>
+    </message>
+</context>
 <context>
     <name>Intro</name>
     <message>
@@ -691,6 +876,10 @@
         <source>Form</source>
         <translation>Inprimakia</translation>
     </message>
+    <message>
+        <source>Number of blocks left</source>
+        <translation>Gainerako blokeen kopurua.</translation>
+    </message>
     <message>
         <source>Unknown...</source>
         <translation>Ezezaguna...</translation>
@@ -699,6 +888,10 @@
         <source>Last block time</source>
         <translation>Azken blokearen unea</translation>
     </message>
+    <message>
+        <source>Progress</source>
+        <translation>Aurrerapena</translation>
+    </message>
     <message>
         <source>calculating...</source>
         <translation>kalkulatzen...</translation>
@@ -707,9 +900,17 @@
         <source>Hide</source>
         <translation>Izkutatu</translation>
     </message>
+    <message>
+        <source>Esc</source>
+        <translation>Esc</translation>
+    </message>
     </context>
 <context>
     <name>OpenURIDialog</name>
+    <message>
+        <source>Open bitcoin URI</source>
+        <translation>Ireki bitcoin URIa</translation>
+    </message>
     <message>
         <source>URI:</source>
         <translation>URI: </translation>
@@ -729,7 +930,11 @@
         <source>default wallet</source>
         <translation>Diruzorro lehenetsia</translation>
     </message>
-    </context>
+    <message>
+        <source>Opening Wallet &lt;b&gt;%1&lt;/b&gt;...</source>
+        <translation>Diru-zorroa irekitzen &lt;b&gt;%1&lt;/b&gt;...</translation>
+    </message>
+</context>
 <context>
     <name>OptionsDialog</name>
     <message>
@@ -744,6 +949,78 @@
         <source>Size of &amp;database cache</source>
         <translation>Databasearen cache tamaina</translation>
     </message>
+    <message>
+        <source>IP address of the proxy (e.g. IPv4: 127.0.0.1 / IPv6: ::1)</source>
+        <translation>Proxyaren IP helbidea  (IPv4: 127.0.0.1 / IPv6: ::1 adibidez )</translation>
+    </message>
+    <message>
+        <source>&amp;Hide tray icon</source>
+        <translation>&amp;Erretiluaren ikonoa ezkutatu</translation>
+    </message>
+    <message>
+        <source>Open Configuration File</source>
+        <translation>Ireki konfigurazio fitxategia</translation>
+    </message>
+    <message>
+        <source>Reset all client options to default.</source>
+        <translation>Bezeroaren aukera guztiak hasieratu.</translation>
+    </message>
+    <message>
+        <source>&amp;Reset Options</source>
+        <translation>&amp;Aukerak Hasieratu</translation>
+    </message>
+    <message>
+        <source>&amp;Network</source>
+        <translation>&amp;Sarea</translation>
+    </message>
+    <message>
+        <source>GB</source>
+        <translation>GB</translation>
+    </message>
+    <message>
+        <source>MiB</source>
+        <translation>MiB</translation>
+    </message>
+    <message>
+        <source>Expert</source>
+        <translation>Aditu</translation>
+    </message>
+    <message>
+        <source>Enable coin &amp;control features</source>
+        <translation>Diruaren &amp;kontrolaren ezaugarriak gaitu</translation>
+    </message>
+    <message>
+        <source>Map port using &amp;UPnP</source>
+        <translation>Portua mapeatu &amp;UPnP erabiliz</translation>
+    </message>
+    <message>
+        <source>Accept connections from outside.</source>
+        <translation>Kanpoko konexioak onartu</translation>
+    </message>
+    <message>
+        <source>Allow incomin&amp;g connections</source>
+        <translation>Sarbide konexioak baimendu</translation>
+    </message>
+    <message>
+        <source>Proxy &amp;IP:</source>
+        <translation>Proxyaren &amp;IP helbidea:</translation>
+    </message>
+    <message>
+        <source>&amp;Port:</source>
+        <translation>&amp;Portua:</translation>
+    </message>
+    <message>
+        <source>Port of the proxy (e.g. 9050)</source>
+        <translation>Proxy portua (9050 adibidez)</translation>
+    </message>
+    <message>
+        <source>IPv4</source>
+        <translation>IPv4</translation>
+    </message>
+    <message>
+        <source>IPv6</source>
+        <translation>IPv6</translation>
+    </message>
     <message>
         <source>Tor</source>
         <translation>Tor</translation>
@@ -756,6 +1033,10 @@
         <source>&amp;Display</source>
         <translation>&amp;Pantaila</translation>
     </message>
+    <message>
+        <source>User Interface &amp;language:</source>
+        <translation>Erabiltzaile-interfazearen &amp;hizkuntza:</translation>
+    </message>
     <message>
         <source>&amp;Unit to show amounts in:</source>
         <translation>Zenbatekoa azaltzeko &amp;unitatea:</translation>
@@ -768,10 +1049,22 @@
         <source>&amp;Cancel</source>
         <translation>&amp;Ezeztatu</translation>
     </message>
+    <message>
+        <source>default</source>
+        <translation>lehenetsi</translation>
+    </message>
     <message>
         <source>none</source>
         <translation>Bat ere ez</translation>
     </message>
+    <message>
+        <source>Confirm options reset</source>
+        <translation>Berretsi aukeren berrezarpena</translation>
+    </message>
+    <message>
+        <source>Client restart required to activate changes.</source>
+        <translation>Bezeroa berrabiarazi behar da aldaketak aktibatzeko.</translation>
+    </message>
     <message>
         <source>Configuration options</source>
         <translation>Konfiguraketa aukerak</translation>
@@ -791,10 +1084,22 @@
         <source>Form</source>
         <translation>Inprimakia</translation>
     </message>
+    <message>
+        <source>Watch-only:</source>
+        <translation>Ikusi-bakarrik:</translation>
+    </message>
+    <message>
+        <source>Available:</source>
+        <translation>Eskuragarri:</translation>
+    </message>
     <message>
         <source>Pending:</source>
         <translation>Zai:</translation>
     </message>
+    <message>
+        <source>Immature:</source>
+        <translation>Ez dago eskuragarri:</translation>
+    </message>
     <message>
         <source>Total:</source>
         <translation>Guztira:</translation>
@@ -802,12 +1107,40 @@
     </context>
 <context>
     <name>PSBTOperationsDialog</name>
+    <message>
+        <source>Copy to Clipboard</source>
+        <translation>Kopiatu arbelera</translation>
+    </message>
+    <message>
+        <source>Save...</source>
+        <translation>Gorde...</translation>
+    </message>
+    <message>
+        <source>Close</source>
+        <translation>Itxi</translation>
+    </message>
     </context>
 <context>
     <name>PaymentServer</name>
+    <message>
+        <source>Payment request error</source>
+        <translation>Ordainketa eskaera akatsa</translation>
+    </message>
+    <message>
+        <source>Invalid payment address %1</source>
+        <translation>Ordainketa helbide baliogabea %1</translation>
+    </message>
     </context>
 <context>
     <name>PeerTableModel</name>
+    <message>
+        <source>User Agent</source>
+        <translation>Erabiltzaile agentea</translation>
+    </message>
+    <message>
+        <source>Node/Service</source>
+        <translation>Adabegi / Zerbitzua</translation>
+    </message>
     </context>
 <context>
     <name>QObject</name>
@@ -829,6 +1162,14 @@
     </context>
 <context>
     <name>RPCConsole</name>
+    <message>
+        <source>User Agent</source>
+        <translation>Erabiltzaile agentea</translation>
+    </message>
+    <message>
+        <source>Node window</source>
+        <translation>Adabegiaren leihoa</translation>
+    </message>
     <message>
         <source>Last block time</source>
         <translation>Azken blokearen unea</translation>
@@ -852,6 +1193,10 @@
         <source>Copy label</source>
         <translation>Etiketa kopiatu</translation>
     </message>
+    <message>
+        <source>Copy amount</source>
+        <translation>zenbatekoaren kopia</translation>
+    </message>
     <message>
         <source>Could not unlock wallet.</source>
         <translation>Ezin da diruzorroa desblokeatu.</translation>
@@ -913,6 +1258,14 @@
         <source>Amount:</source>
         <translation>Kopurua:</translation>
     </message>
+    <message>
+        <source>Fee:</source>
+        <translation>Ordainketa:</translation>
+    </message>
+    <message>
+        <source>After Fee:</source>
+        <translation>Ordaindu ondoren:</translation>
+    </message>
     <message>
         <source>Change:</source>
         <translation>Bueltak:</translation>
@@ -937,6 +1290,26 @@
         <source>Confirm the send action</source>
         <translation>Bidalketa berretsi</translation>
     </message>
+    <message>
+        <source>Copy quantity</source>
+        <translation>Kopia kopurua</translation>
+    </message>
+    <message>
+        <source>Copy amount</source>
+        <translation>zenbatekoaren kopia</translation>
+    </message>
+    <message>
+        <source>Copy bytes</source>
+        <translation>Kopiatu byte-ak</translation>
+    </message>
+    <message>
+        <source>Copy dust</source>
+        <translation>Kopiatu hautsa</translation>
+    </message>
+    <message>
+        <source>Copy change</source>
+        <translation>Kopiatu aldaketa</translation>
+    </message>
     <message>
         <source>Confirm send coins</source>
         <translation>Txanponen bidalketa berretsi</translation>
@@ -1002,6 +1375,22 @@
         <source>Alt+P</source>
         <translation>Alt+P</translation>
     </message>
+    <message>
+        <source>No error</source>
+        <translation>Ez dago errorerik</translation>
+    </message>
+    <message>
+        <source>Message signing failed.</source>
+        <translation>Errorea mezua sinatzean</translation>
+    </message>
+    <message>
+        <source>Message signed.</source>
+        <translation>Mezua sinatuta.</translation>
+    </message>
+    <message>
+        <source>Please check the signature and try again.</source>
+        <translation>Mesedez, begiratu sinadura eta saiatu berriro.</translation>
+    </message>
     </context>
 <context>
     <name>TrafficGraphWidget</name>
@@ -1012,6 +1401,10 @@
         <source>Open until %1</source>
         <translation>Zabalik %1 arte</translation>
     </message>
+    <message>
+        <source>abandoned</source>
+        <translation>abandonatuta</translation>
+    </message>
     <message>
         <source>%1/unconfirmed</source>
         <translation>%1/konfirmatu gabe</translation>
@@ -1020,14 +1413,66 @@
         <source>%1 confirmations</source>
         <translation>%1 konfirmazio</translation>
     </message>
+    <message>
+        <source>Status</source>
+        <translation>Egoera</translation>
+    </message>
     <message>
         <source>Date</source>
         <translation>Data</translation>
     </message>
+    <message>
+        <source>Source</source>
+        <translation>Iturria</translation>
+    </message>
+    <message>
+        <source>Generated</source>
+        <translation>Sortua</translation>
+    </message>
+    <message>
+        <source>From</source>
+        <translation>Tik</translation>
+    </message>
     <message>
         <source>unknown</source>
         <translation>ezezaguna</translation>
     </message>
+    <message>
+        <source>To</source>
+        <translation>Ra</translation>
+    </message>
+    <message>
+        <source>own address</source>
+        <translation>zure helbidea</translation>
+    </message>
+    <message>
+        <source>watch-only</source>
+        <translation>ikusi bakarrik</translation>
+    </message>
+    <message>
+        <source>label</source>
+        <translation>etiketa</translation>
+    </message>
+    <message>
+        <source>Credit</source>
+        <translation>Kreditua</translation>
+    </message>
+    <message>
+        <source>not accepted</source>
+        <translation>Onartu gabe</translation>
+    </message>
+    <message>
+        <source>Debit</source>
+        <translation>Zorrak</translation>
+    </message>
+    <message>
+        <source>Total debit</source>
+        <translation>Zor totala</translation>
+    </message>
+    <message>
+        <source>Total credit</source>
+        <translation>Kreditu totala</translation>
+    </message>
     <message>
         <source>Message</source>
         <translation>Mezua</translation>
@@ -1090,6 +1535,10 @@
         <source>Mined</source>
         <translation>Meatua</translation>
     </message>
+    <message>
+        <source>watch-only</source>
+        <translation>ikusi bakarrik</translation>
+    </message>
     <message>
         <source>(n/a)</source>
         <translation>(n/a)</translation>
@@ -1177,6 +1626,14 @@
         <source>Copy label</source>
         <translation>Etiketa kopiatu</translation>
     </message>
+    <message>
+        <source>Copy amount</source>
+        <translation>zenbatekoaren kopia</translation>
+    </message>
+    <message>
+        <source>Copy transaction ID</source>
+        <translation>Kopiatu transakzioaren IDa</translation>
+    </message>
     <message>
         <source>Comma separated file (*.csv)</source>
         <translation>Komaz bereizitako artxiboa (*.csv)</translation>
@@ -1215,6 +1672,10 @@
         <source>Close wallet</source>
         <translation>Diruzorroa itxi</translation>
     </message>
+    <message>
+        <source>Close all wallets</source>
+        <translation>Diruzorro guztiak itxi</translation>
+    </message>
     </context>
 <context>
     <name>WalletFrame</name>
