@@ -146,6 +146,10 @@
     </context>
 <context>
     <name>CreateWalletDialog</name>
+    <message>
+        <source>Wallet</source>
+        <translation>Әмиян</translation>
+    </message>
     </context>
 <context>
     <name>EditAddressDialog</name>
@@ -198,6 +202,9 @@
 <context>
     <name>OverviewPage</name>
     </context>
+<context>
+    <name>PSBTOperationsDialog</name>
+    </context>
 <context>
     <name>PaymentServer</name>
     </context>
@@ -235,14 +242,10 @@
 <context>
     <name>ReceiveRequestDialog</name>
     <message>
-        <source>Amount</source>
+        <source>Amount:</source>
         <translation>Саны</translation>
     </message>
-    <message>
-        <source>Wallet</source>
-        <translation>Әмиян</translation>
-    </message>
-</context>
+    </context>
 <context>
     <name>RecentRequestsTableModel</name>
     <message>
@@ -335,6 +338,10 @@
         <source>&amp;Export</source>
         <translation>Экспорт</translation>
     </message>
+    <message>
+        <source>Error</source>
+        <translation>қате</translation>
+    </message>
     </context>
 <context>
     <name>bitcoin-core</name>
