@@ -341,11 +341,7 @@
         <source>Wallet is &lt;b&gt;encrypted&lt;/b&gt; and currently &lt;b&gt;locked&lt;/b&gt;</source>
         <translation>Maka-&lt;b&gt;encrypt&lt;/b&gt; ya ing wallet at kasalukuyan yang maka-&lt;b&gt;locked&lt;/b&gt;</translation>
     </message>
-    <message>
-        <source>A fatal error occurred. Bitcoin can no longer continue safely and will quit.</source>
-        <translation>Atin kamalian a milyari. Ali ne magsilbing sumulung pa ing Bitcoin at kailangan na ng tuknang.</translation>
-    </message>
-</context>
+    </context>
 <context>
     <name>CoinControlDialog</name>
     <message>
@@ -386,6 +382,10 @@
     </context>
 <context>
     <name>CreateWalletDialog</name>
+    <message>
+        <source>Wallet</source>
+        <translation>Wallet</translation>
+    </message>
     </context>
 <context>
     <name>EditAddressDialog</name>
@@ -594,6 +594,9 @@
         <translation>Ing kekang kasalungsungan kabuuang balanse</translation>
     </message>
     </context>
+<context>
+    <name>PSBTOperationsDialog</name>
+    </context>
 <context>
     <name>PaymentServer</name>
     </context>
@@ -648,10 +651,6 @@
         <source>Block chain</source>
         <translation>Block chain</translation>
     </message>
-    <message>
-        <source>Current number of blocks</source>
-        <translation>Kasalungsungan bilang dareng blocks</translation>
-    </message>
     <message>
         <source>Last block time</source>
         <translation>Tatauling oras na ning block</translation>
@@ -691,34 +690,26 @@
         <source>Copy amount</source>
         <translation>Kopyan ing alaga</translation>
     </message>
-</context>
+    <message>
+        <source>Could not unlock wallet.</source>
+        <translation>Ali ya bisang mag-unlock ing wallet</translation>
+    </message>
+    </context>
 <context>
     <name>ReceiveRequestDialog</name>
+    <message>
+        <source>Amount:</source>
+        <translation>Alaga:</translation>
+    </message>
+    <message>
+        <source>Message:</source>
+        <translation>Mensayi:</translation>
+    </message>
     <message>
         <source>Copy &amp;Address</source>
         <translation>&amp;Kopyan ing address</translation>
     </message>
-    <message>
-        <source>Address</source>
-        <translation>Address</translation>
-    </message>
-    <message>
-        <source>Amount</source>
-        <translation>Alaga</translation>
-    </message>
-    <message>
-        <source>Label</source>
-        <translation>Label</translation>
-    </message>
-    <message>
-        <source>Message</source>
-        <translation>Mensayi</translation>
-    </message>
-    <message>
-        <source>Wallet</source>
-        <translation>Wallet</translation>
-    </message>
-</context>
+    </context>
 <context>
     <name>RecentRequestsTableModel</name>
     <message>
@@ -1279,6 +1270,10 @@
     </context>
 <context>
     <name>WalletView</name>
+    <message>
+        <source>Error</source>
+        <translation>Mali</translation>
+    </message>
     </context>
 <context>
     <name>bitcoin-core</name>
