@@ -142,6 +142,10 @@
     </context>
 <context>
     <name>CreateWalletDialog</name>
+    <message>
+        <source>Wallet</source>
+        <translation>Chikwama</translation>
+    </message>
     </context>
 <context>
     <name>EditAddressDialog</name>
@@ -174,6 +178,9 @@
 <context>
     <name>OverviewPage</name>
     </context>
+<context>
+    <name>PSBTOperationsDialog</name>
+    </context>
 <context>
     <name>PaymentServer</name>
     </context>
@@ -230,23 +237,7 @@
     </context>
 <context>
     <name>ReceiveRequestDialog</name>
-    <message>
-        <source>Address</source>
-        <translation>Kero</translation>
-    </message>
-    <message>
-        <source>Amount</source>
-        <translation>Marii</translation>
-    </message>
-    <message>
-        <source>Label</source>
-        <translation>Zita</translation>
-    </message>
-    <message>
-        <source>Wallet</source>
-        <translation>Chikwama</translation>
-    </message>
-</context>
+    </context>
 <context>
     <name>RecentRequestsTableModel</name>
     <message>
@@ -272,9 +263,6 @@
 <context>
     <name>SendCoinsEntry</name>
     </context>
-<context>
-    <name>SendConfirmationDialog</name>
-    </context>
 <context>
     <name>ShutdownWindow</name>
     </context>
