@@ -413,11 +413,7 @@
         <source>Wallet is &lt;b&gt;encrypted&lt;/b&gt; and currently &lt;b&gt;locked&lt;/b&gt;</source>
         <translation>Ҳамён &lt;b&gt;кодланган&lt;/b&gt; ва вақтинча &lt;b&gt;қулфланган&lt;/b&gt;</translation>
     </message>
-    <message>
-        <source>A fatal error occurred. Bitcoin can no longer continue safely and will quit.</source>
-        <translation>Жиддий хато юз берди. Bitcoin хавфсиз ишлай олмайди, шунинг учун чиқиб кетилади.</translation>
-    </message>
-</context>
+    </context>
 <context>
     <name>CoinControlDialog</name>
     <message>
@@ -558,6 +554,10 @@
     </context>
 <context>
     <name>CreateWalletDialog</name>
+    <message>
+        <source>Wallet</source>
+        <translation>Ҳамён</translation>
+    </message>
     </context>
 <context>
     <name>EditAddressDialog</name>
@@ -865,7 +865,14 @@
         <source>Current total balance in watch-only addresses</source>
         <translation>Жорий умумий баланс фақат кўринадиган манзилларда</translation>
     </message>
-</context>
+    </context>
+<context>
+    <name>PSBTOperationsDialog</name>
+    <message>
+        <source>or</source>
+        <translation>ёки</translation>
+    </message>
+    </context>
 <context>
     <name>PaymentServer</name>
     <message>
@@ -1020,10 +1027,6 @@
         <source>Services</source>
         <translation>Хизматлар</translation>
     </message>
-    <message>
-        <source>Ban Score</source>
-        <translation>Тезликни бан қилиш</translation>
-    </message>
     <message>
         <source>Connection Time</source>
         <translation>Уланиш вақти</translation>
@@ -1092,14 +1095,6 @@
         <source>Outbound</source>
         <translation>Ташқи йўналиш</translation>
     </message>
-    <message>
-        <source>Yes</source>
-        <translation>Ҳа</translation>
-    </message>
-    <message>
-        <source>No</source>
-        <translation>Йўқ</translation>
-    </message>
     <message>
         <source>Unknown</source>
         <translation>Номаълум</translation>
@@ -1171,12 +1166,20 @@
         <source>Copy amount</source>
         <translation>Кийматни нусхала</translation>
     </message>
-</context>
+    <message>
+        <source>Could not unlock wallet.</source>
+        <translation>Ҳамён қулфдан чиқмади.</translation>
+    </message>
+    </context>
 <context>
     <name>ReceiveRequestDialog</name>
     <message>
-        <source>QR Code</source>
-        <translation>QR Коди</translation>
+        <source>Amount:</source>
+        <translation>Миқдори:</translation>
+    </message>
+    <message>
+        <source>Message:</source>
+        <translation>Хабар</translation>
     </message>
     <message>
         <source>Copy &amp;Address</source>
@@ -1194,30 +1197,6 @@
         <source>Payment information</source>
         <translation>Тўлов маълумоти</translation>
     </message>
-    <message>
-        <source>URI</source>
-        <translation>URI</translation>
-    </message>
-    <message>
-        <source>Address</source>
-        <translation>Манзил</translation>
-    </message>
-    <message>
-        <source>Amount</source>
-        <translation>Миқдори</translation>
-    </message>
-    <message>
-        <source>Label</source>
-        <translation>Ёрлиқ</translation>
-    </message>
-    <message>
-        <source>Message</source>
-        <translation>Хабар</translation>
-    </message>
-    <message>
-        <source>Wallet</source>
-        <translation>Ҳамён</translation>
-    </message>
 </context>
 <context>
     <name>RecentRequestsTableModel</name>
@@ -1793,11 +1772,7 @@
     </context>
 <context>
     <name>WalletFrame</name>
-    <message>
-        <source>No wallet has been loaded.</source>
-        <translation>Хали бирорта хамён юкланмади</translation>
-    </message>
-</context>
+    </context>
 <context>
     <name>WalletModel</name>
     <message>
@@ -1815,6 +1790,10 @@
         <source>Export the data in the current tab to a file</source>
         <translation>Жорий ички ойна ичидаги маълумотларни файлга экспорт қилиш</translation>
     </message>
+    <message>
+        <source>Error</source>
+        <translation>Хатолик</translation>
+    </message>
     </context>
 <context>
     <name>bitcoin-core</name>
