@@ -1,6 +1,10 @@
 <TS language="uz@Latn" version="2.1">
 <context>
     <name>AddressBookPage</name>
+    <message>
+        <source>Right-click to edit address or label</source>
+        <translation>Manzil yoki yorliqni tahrirlash uchun oʻng tugmani bosing</translation>
+    </message>
     <message>
         <source>Create a new address</source>
         <translation>Yangi manzil yaratish</translation>
@@ -82,6 +86,9 @@
 <context>
     <name>OverviewPage</name>
     </context>
+<context>
+    <name>PSBTOperationsDialog</name>
+    </context>
 <context>
     <name>PaymentServer</name>
     </context>
@@ -102,14 +109,6 @@
     </context>
 <context>
     <name>ReceiveRequestDialog</name>
-    <message>
-        <source>Address</source>
-        <translation>Manzil</translation>
-    </message>
-    <message>
-        <source>Label</source>
-        <translation>Yorliq</translation>
-    </message>
     </context>
 <context>
     <name>RecentRequestsTableModel</name>
