@@ -29,6 +29,10 @@
         <source>Delete the currently selected address from the list</source>
         <translation>把目前選擇的位址從列表中刪除</translation>
     </message>
+    <message>
+        <source>Enter address or label to search</source>
+        <translation>輸入位址或標記以作搜尋</translation>
+    </message>
     <message>
         <source>Export the data in the current tab to a file</source>
         <translation>把目前分頁的資料匯出至檔案</translation>
@@ -127,6 +131,10 @@
         <source>Repeat new passphrase</source>
         <translation>重複新密碼</translation>
     </message>
+    <message>
+        <source>Show passphrase</source>
+        <translation>顯示密碼</translation>
+    </message>
     <message>
         <source>Encrypt wallet</source>
         <translation>加密錢包</translation>
@@ -167,6 +175,30 @@
         <source>Wallet encrypted</source>
         <translation>錢包已加密</translation>
     </message>
+    <message>
+        <source>Enter the new passphrase for the wallet.&lt;br/&gt;Please use a passphrase of &lt;b&gt;ten or more random characters&lt;/b&gt;, or &lt;b&gt;eight or more words&lt;/b&gt;.</source>
+        <translation>輸入錢包的新密碼。&lt;br/&gt;密碼請用&lt;b&gt;10 個或以上的隨機字元&lt;/b&gt;，或是&lt;b&gt;8 個或以上的字詞&lt;/b&gt;。</translation>
+    </message>
+    <message>
+        <source>Enter the old passphrase and new passphrase for the wallet.</source>
+        <translation>請輸入舊密碼和新密碼至錢包。</translation>
+    </message>
+    <message>
+        <source>Remember that encrypting your wallet cannot fully protect your bitcoins from being stolen by malware infecting your computer.</source>
+        <translation>請記得將錢包加密不能完全防止你的 Bitcoins 經被入侵電腦的惡意程式偷取。</translation>
+    </message>
+    <message>
+        <source>Wallet to be encrypted</source>
+        <translation>需要加密的錢包</translation>
+    </message>
+    <message>
+        <source>Your wallet is about to be encrypted. </source>
+        <translation>您的錢包將被加密</translation>
+    </message>
+    <message>
+        <source>Your wallet is now encrypted. </source>
+        <translation>您的錢包剛剛完成加密</translation>
+    </message>
     <message>
         <source>IMPORTANT: Any previous backups you have made of your wallet file should be replaced with the newly generated, encrypted wallet file. For security reasons, previous backups of the unencrypted wallet file will become useless as soon as you start using the new, encrypted wallet.</source>
         <translation>重要: 請改用新產生的加密錢包檔，來取代所以舊錢包檔的備份。為安全計，當你開始使用新的加密錢包檔後，舊錢包檔的備份就不能再使用了。</translation>
@@ -289,6 +321,18 @@
         <source>Open &amp;URI...</source>
         <translation>開啓網址... &amp;U</translation>
     </message>
+    <message>
+        <source>Create Wallet...</source>
+        <translation>建立錢包...</translation>
+    </message>
+    <message>
+        <source>Create a new wallet</source>
+        <translation>新增一個錢包</translation>
+    </message>
+    <message>
+        <source>Wallet:</source>
+        <translation>錢包:</translation>
+    </message>
     <message>
         <source>Reindexing blocks on disk...</source>
         <translation>正在為磁碟區塊重建索引...</translation>
@@ -357,15 +401,49 @@
         <source>Information</source>
         <translation>資訊</translation>
     </message>
+    <message>
+        <source>Up to date</source>
+        <translation>已更新至最新版本</translation>
+    </message>
+    <message>
+        <source>Open Wallet</source>
+        <translation>開啟錢包</translation>
+    </message>
+    <message>
+        <source>Open a wallet</source>
+        <translation>開啟一個錢包</translation>
+    </message>
+    <message>
+        <source>default wallet</source>
+        <translation>預設錢包</translation>
+    </message>
+    <message>
+        <source>Main Window</source>
+        <translation>主視窗</translation>
+    </message>
+    <message>
+        <source>Error: %1</source>
+        <translation>錯誤: %1</translation>
+    </message>
     <message>
         <source>Date: %1
 </source>
         <translation>日期: %1
+</translation>
+    </message>
+    <message>
+        <source>Wallet: %1
+</source>
+        <translation>錢包: %1
 </translation>
     </message>
     </context>
 <context>
     <name>CoinControlDialog</name>
+    <message>
+        <source>Confirmed</source>
+        <translation>已確認</translation>
+    </message>
     <message>
         <source>(no label)</source>
         <translation>(無標記)</translation>
@@ -376,6 +454,10 @@
     </context>
 <context>
     <name>CreateWalletDialog</name>
+    <message>
+        <source>Wallet</source>
+        <translation>錢包</translation>
+    </message>
     </context>
 <context>
     <name>EditAddressDialog</name>
@@ -405,6 +487,10 @@
     </context>
 <context>
     <name>OpenWalletActivity</name>
+    <message>
+        <source>default wallet</source>
+        <translation>預設錢包</translation>
+    </message>
     </context>
 <context>
     <name>OptionsDialog</name>
@@ -495,6 +581,10 @@
         <source>%n year(s)</source>
         <translation><numerusform>%n 年</numerusform></translation>
     </message>
+    <message>
+        <source>Error: %1</source>
+        <translation>錯誤: %1</translation>
+    </message>
     </context>
 <context>
     <name>QRImageWidget</name>
@@ -539,6 +629,10 @@
     </context>
 <context>
     <name>ReceiveRequestDialog</name>
+    <message>
+        <source>Wallet:</source>
+        <translation>錢包:</translation>
+    </message>
     </context>
 <context>
     <name>RecentRequestsTableModel</name>
@@ -601,6 +695,10 @@
         <source>Comma separated file (*.csv)</source>
         <translation>逗號分隔檔 (*.csv)</translation>
     </message>
+    <message>
+        <source>Confirmed</source>
+        <translation>已確認</translation>
+    </message>
     <message>
         <source>Label</source>
         <translation>標記</translation>
@@ -622,10 +720,18 @@
     </context>
 <context>
     <name>WalletFrame</name>
-    </context>
+    <message>
+        <source>Create a new wallet</source>
+        <translation>新增一個錢包</translation>
+    </message>
+</context>
 <context>
     <name>WalletModel</name>
-    </context>
+    <message>
+        <source>default wallet</source>
+        <translation>預設錢包</translation>
+    </message>
+</context>
 <context>
     <name>WalletView</name>
     <message>
